@@ -9,6 +9,7 @@ from django.db import models
 from django.db.models import signals
 from django.db.models.fields import BLANK_CHOICE_DASH
 from django.template.defaultfilters import truncatechars
+from django.utils.crypto import get_random_string
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
 from django.utils.text import slugify
@@ -34,6 +35,9 @@ class FormType(Type):
         return value
 
 
+RANDOM_STRING_CHARS = "abcdefghijklmnopqrstuvwxyz0123456789"
+
+
 class NameField(models.CharField):
     """Almost but not quite a slug field. We only allow snake_case_names."""
 
@@ -65,6 +69,16 @@ class NameField(models.CharField):
         name, path, args, kwargs = super().deconstruct()
         return name, "django.db.models.CharField", args, kwargs
 
+    def formfield(self, **kwargs):
+        kwargs.setdefault("required", False)
+        return super().formfield(**kwargs)
+
+    def to_python(self, value):
+        value = super().to_python(value)
+        if not value:
+            return f"field_{get_random_string(10, allowed_chars=RANDOM_STRING_CHARS)}"
+        return value
+
 
 class FormFieldBase(models.Model):
     """
